NLSL: parsav.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
parsav.f90 File Reference

Go to the source code of this file.

## Modules
module | parsav

## Variables
double precision, dimension(6, mxvar), save | parsav::fxsave
double precision, dimension(nfprm, mxsite), save | parsav::fprsav
double precision, dimension(4, mxspc), save | parsav::spsave
integer, dimension(3, mxvar), save | parsav::ixsave
integer, dimension(niprm, mxsite), save | parsav::iprsav
integer, dimension(nfprm, mxsite), save | parsav::ixxsav
integer, save | parsav::nstsav
integer, save | parsav::nspsav
integer, save | parsav::nprsav
logical, save | parsav::xsaved
logical, save | parsav::prsaved
character *9, dimension(mxvar), save | parsav::tagsav